from setuptools import setup

setup(name='AlgumTesteCoisa',
      version='0.2',
      description='Função para dar um oi.',
      long_description = 'file: README.md',
      author='VictorSalg',
      author_email='victorfsalgueiros@gmail.com',
     )